Note: This bug is displayed in read-only format because the product is no longer active in Red Hat Bugzilla.

Bug 1722734

Summary: 'qemu-img convert' images over RBD is very very slow
Product: Red Hat Enterprise Linux Advanced Virtualization Reporter: Tingting Mao <timao>
Component: qemu-kvmAssignee: Virtualization Maintenance <virt-maint>
qemu-kvm sub component: Ceph QA Contact: zixchen
Status: CLOSED WONTFIX Docs Contact:
Severity: medium    
Priority: medium CC: coli, jinzhao, juzhang, ngu, qzhang, sgarzare, virt-maint, zhenyzha
Version: 8.0Keywords: Triaged
Target Milestone: rcFlags: pm-rhel: mirror+
Target Release: ---   
Hardware: Unspecified   
OS: Unspecified   
Whiteboard:
Fixed In Version: Doc Type: If docs needed, set a value
Doc Text:
Story Points: ---
Clone Of: Environment:
Last Closed: 2021-03-15 07:36:55 UTC Type: Bug
Regression: --- Mount Type: ---
Documentation: --- CRM:
Verified Versions: Category: ---
oVirt Team: --- RHEL 7.3 requirements from Atomic Host:
Cloudforms Team: --- Target Upstream Version:
Embargoed:

Description Tingting Mao 2019-06-21 06:48:39 UTC
Description of problem:
Covert images over RBD is very slow, the consumed time is almost 73 times compared to the time in local.


Version-Release number of selected component (if applicable):
qemu-kvm-4.0.0-4.module+el8.1.0+3356+cda7f1ee
kernel-4.18.0-100.el8.x86_64


How reproducible:
100%


Steps to Reproduce:
1. Check the source image info
# qemu-img info tgt.qcow2 
image: tgt.qcow2
file format: qcow2
virtual size: 20G (21474836480 bytes)
disk size: 5.4G
cluster_size: 65536
Format specific information:
    compat: 1.1
    lazy refcounts: false
    refcount bits: 16
    corrupt: false

2.Convert to target image in local
# time qemu-img convert -f qcow2 -O raw tgt.qcow2 target.img -p
    (100.00/100%)

real	0m5.008s ----------------- Fast!
user	0m0.665s
sys	0m7.229s

3. Covert to target image over RBD
# time qemu-img convert -f qcow2 -O raw tgt.qcow2 rbd:kvmtest-pool/tgt.img -p
    (100.00/100%)

real	6m6.204s ----------------- Slow!
user	0m13.993s
sys	0m4.553s


Actual results:
As above.


Expected results:
The speed for convert images over RBD faster.


Additional info:

Comment 3 Ademar Reis 2020-02-05 22:59:29 UTC
QEMU has been recently split into sub-components and as a one-time operation to avoid breakage of tools, we are setting the QEMU sub-component of this BZ to "General". Please review and change the sub-component if necessary the next time you review this BZ. Thanks

Comment 7 RHEL Program Management 2021-03-15 07:36:55 UTC
After evaluating this issue, there are no plans to address it further or fix it in an upcoming release.  Therefore, it is being closed.  If plans change such that this issue will be fixed in an upcoming release, then the bug can be reopened.

Comment 8 zixchen 2021-03-16 10:30:24 UTC
Based on bug 1744525 discussion, rbd with qcow2 is not recommended, so QE agrees to close this bug for now.